#
# spec file for package bazel0.19
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bazel0.19
Version:        0.19.2
Release:        bp156.3.10
Summary:        Tool for the automation of building and testing of software
License:        Apache-2.0
Group:          Development/Tools/Building
URL:            http://bazel.io/
Source0:        https://github.com/bazelbuild/bazel/releases/download/%{version}/bazel-%{version}-dist.zip
Source1:        https://github.com/bazelbuild/bazel/releases/download/%{version}/bazel-%{version}-dist.zip.sig
BuildRequires:  gcc-c++
BuildRequires:  java-1_8_0-openjdk-devel
BuildRequires:  python
BuildRequires:  unzip
BuildRequires:  zip
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(bash-completion)

Requires:       java-1_8_0-openjdk-devel

Provides:       bazel = %{version}
Conflicts:      bazel > %{version}

ExcludeArch:    armv7l i586

%define bashcompdir %(pkg-config --variable=completionsdir bash-completion 2>/dev/null)

%description
Tool for the automation of building and testing of software. It supports Java,
C++ and Go as programing languages. It also has a support for Android and iOS
as mobile operating systems.

%prep
%setup -q -c
# Remove executable permissions
chmod 0644 AUTHORS CHANGELOG.md CONTRIBUTORS LICENSE
# Fix collision between grpc's gettid and glibc's gettid
find third_party/grpc -type f -name "*.c" -exec sed -i -e 's|gettid(|my_gettid(|g' {} +

%build
%ifarch %arm aarch64
export BAZEL_JAVAC_OPTS="-J-Xmx2g -J-Xms200m"
%endif
CC=gcc
CXX=g++
./compile.sh
./output/bazel shutdown

%install
export NO_BRP_STRIP_DEBUG=true
export NO_DEBUGINFO_STRIP_DEBUG=true
%define __debug_install_post %nil
: >debugfiles.list
: >debugsources.list
: >debugsourcefiles.list

install -Dm0755 output/bazel %{buildroot}%{_bindir}/bazel-%{version}
ln -s %{_bindir}/bazel-%{version} %{buildroot}%{_bindir}/bazel

%files
%defattr(-,root,root)
%doc AUTHORS CHANGELOG.md CONTRIBUTORS
%license LICENSE
%{_bindir}/bazel-%{version}
%{_bindir}/bazel

%changelog
* Thu Oct 17 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix collision between grpc's gettid and glibc's gettid
* Fri Sep 13 2019 Christian Goll <cgoll@suse.com>
- removed i586 buils as they are failing
* Thu Jun  6 2019 Christian Goll <cgoll@suse.com>
- conflicts with bazel version > 0.19.2
* Thu Jun  6 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update _constraints
- Fix %%arm builds
* Wed Jun  5 2019 Christian Goll <cgoll@suse.com>
- removed update-alternavtives as its only used for building
  tensorflow and updated name for Factory submissions
* Tue May 28 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add _constraints to avoid OOM errors
* Mon May 27 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 0.19.2:
  * f7e5aef:
    Add cc_toolchain targets for the new entries in the default
    cc_toolchain_suite.
  * 683c302:
    Read the CROSSTOOL from the package of the current cc_toolchain,
    not from --crosstool_top
  * Fixes regression #6662, by fixing tools/cpp/BUILD
  * Fixes regression #6665, by setting the toolchain identifier.
  * CROSSTOOL file is now read from the package of cc_toolchain, not from the
    package of cc_toolchain_suite. This is not expected to break anybody since
    cc_toolchain_suite and cc_toolchain are commonly in the same package.
- from 0.19.1:
  * Windows fixes
* Fri May  3 2019 Christian Goll <cgoll@suse.com>
- updated version 0.19.0 to use update-alternatives so that this
  specfic bazel version for building
* Wed Nov  7 2018 Michał Rostecki <mrostecki@suse.de>
- Update to version 0.19.0:
  * The --incompatible_expand_directories flag automatically
    expands directories in command lines. See the design document.
  * The --loading_phase_threads flag now defaults to auto instead
    of 200, which at the moment corresponds to the number of CPUs.
  * Fixed missing debug symbols when building native code with
  - -compilation_mode=dbg that target Android ARM architectures
    by adding the -g flag.
  * Added --incompatible_disable_legacy_flags_cc_toolchain_api to
    deprecate legacy cc_toolchain Starlark API for legacy CROSSTOOL
    fields. Tracking issue is #6434. See the instructions for
    migration.
  * Runfiles in cc_test: the C++ runfiles library
    (@bazel_tools//tools/cpp/runfiles) can now create Runfiles
    objects for tests. See //tools/cpp/runfiles/runfiles_src.h in
    the Bazel source tree for documentation.
  * :cc_binary link action no longer hardcodes -static-libgcc for
    toolchains that support embedded runtimes (guarded by
  - -experimental_dont_emit_static_libgcc temporarily).
  * The flag --experimental_enable_cc_configuration_make_variables
    is removed, use
  - -incompatible_disable_cc_configuration_make_variables instead.
  * Bazel now requires a JDK to be installed as it no longer falls
    back to the internal JDK if the --javabase flag is not set.
    Instead, Bazel now searches for a JDK within the JAVA_HOME and
    PATH environment variables. If Bazel cannot find a JDK, it will
    not be able to run Java builds.
  * LcovMerger was renamed to CoverageOutputGenerator.
  * A new coverage method for C++ rules that uses gcc with the
  - -experimental_cc_coverage flag. The flag will use gcov
    instead of lcov to collect coverage information. This new
    implementation fixes some of the C++ coverage correctness
    issues ( respecting --instrumentation_filter and
  - -instrument_test_targets flags ).
  * Faster clean and incremental times when invoking bazel coverage
    (small overhead compared to test runtimes instead of 2x test
    runtime), but more measurements need to be done.
  * Add --apple_compiler and --apple_grte_top options. These
    provide the equivalent of --compiler / --grte_top for the
    toolchain configured in --apple_crosstool_top.
  * There is now a same_pkg_direct_rdeps query function. See the
    query documentation for more details.
  * Propagating remote errors to the user even if
  - -verbose_failures=false is set.
  * Add number of configured targets to analysis phase status
    output.
  * Bazel now checks stderr instead of stdout to decide if it is
    outputting to a terminal. --isatty is deprecated, use
  - -is_stderr_atty instead.
* Fri Oct 19 2018 cgoll@suse.com
- enabled aarch64 build and disabled armv7l build as this one fails
  due to java memory errors
* Wed Oct 17 2018 Michał Rostecki <mrostecki@suse.de>
- Ensure neutrality of description and summary
- Stop overriding _disable_source_fetch
- Remove unnecessary comments
- Update to version 0.18.0:
  * Include also ext jars in the bootclasspath jar.
  * Fix toolchain_java9 on --host_javabase= after
  * Release notes: fix markdown
  * Fix NestHost length computation
  * Don't rethrow any remote cache failures on either download or
    upload, only warn. Added more tests.
  * Fix broken IdlClassTest on Bazel's CI.
  * Fix the Xcode version detection which got broken by the
    upgrade to Xcode 10.0.
  * Temporarily restore processing of workspace-wide
    tools/bazel.rc file.
  * New bazelrc file list.
  * .bazelignore is now fully functional.
  * The startup flag --host_javabase has been renamed to
  - -server_javabase to avoid confusion with the build flag
  - -host_javabase.
  * The Android resource processing pipeline now supports
    persistence via worker processes. Enable it with
  - -persistent_android_resource_processor. A 50%% increase was
    observed in build speed for clean local builds and up to 150%%
    increase in build speed for incremental local builds.
  * In-memory package //tools/defaults has been removed
    (controlled by --incompatible_disable_tools_defaults_package
    flag).
  * Late bound option defaults (typical example was the --compiler
    flag, when it was not specified, it’s value was computed using
    the CROSSTOOL) are removed (controlled by
  - -incompatible_disable_late_bound_option_defaults flag).
  * Depsets are no longer accepted in user_compile_flags and
    user_link_flags in the C++ toolchain API (controlled by
  - -incompatible_disable_depset_in_cc_user_flags flag) affects
    C++ users.
  * CROSSTOOL is no longer consulted when selecting C++ toolchain
    (controlled by
  - -incompatible_disable_cc_toolchain_label_from_crosstool_proto
    flag).
  * C++ specific Make variables are no longer passed from the
    CppConfiguration, but from the C++ toolchain (controlled by
  - -incompatible_disable_cc_configuration_make_variables flag).
  * Skylark api accessing C++ toolchain in ctx.fragments.cpp is
    removed (controlled by
  - -incompatible_disable_legacy_cpp_toolchain_skylark_api flag).
  * cc_binary link action no longer hardcodes -static-libgcc for
    toolchains that support embedded runtimes (guarded by
  - -experimental_dont_emit_static_libgcc temporarily). Proper
    deprecation using --incompatible flags will follow.
  * Future versions of Bazel will require a locally installed JDK
    for Java development. Previously Bazel would fall back to using
    the embedded --server_javabase if no JDK as available. Pass
  - -incompatible_never_use_embedded_jdk_for_javabase to disable
    the legacy behaviour.
  * --javacopt= no longer affects compilations of tools that are
    executed during the build; use --host_javacopt= to change
    javac flags in the host configuration.
  * objc_library now supports the module_name attribute.
  * Support fileset expansion in ctx.actions.args(). Controlled by
--incompatible_expand_directories.
  * --windows_exe_launcher is deprecated, this flag will be removed
  soon. Please make sure you are not using it.
  * Bazel now supports the symlink runfiles tree on Windows with
  - -experimental_enable_runfiles flag.
  * A new experimental option --experimental_ui_deduplicate has
    been added. It causes the UI to attempt to deduplicate
    messages from actions to keep the console output cleaner.
  * Add --modify_execution_info, a flag to customize action
    execution info.
  * Add ExecutionInfo to aquery output for ExecutionInfoSpecifier
    actions.
  * When computing --instrumentation_filter, end filter patterns
    with "[/:]" to match non-top-level packages exactly and treat
    top-level targets consistently.
  * Added the bazel info server_log command, which obtains the
    main Bazel server log file path. This can help debug Bazel
    issues.
  * aapt shrink resources now properly respect filter
    configurations.
* Mon Oct  8 2018 Michał Rostecki <mrostecki@suse.de>
- Update to version 0.17.2:
  * Update checker framework dataflow and javacutil versions
  * Stop using --release in versioned java_toolchains
  * make_deb: Add new empty line in the end of conffiles file
  * Properly mark configuration files in the Debian package.
  * Add flag --incompatible_symlinked_sandbox_expands_tree_
    artifacts_in_runfiles_tree.
  * Update protobuf to 3.6.1 -- add new files
  * Update protobuf to 3.6.1 -- update references
  * Update protobuf to 3.6.1 -- remove 3.6.0 sources
  * Fix protobuf in the WORKSPACE
  * Revert "Update to JDK 10 javac"
  * Fix tests on JDK 9 and 10
  * Fix more tests on JDK 9 and 10
  * Add ubuntu1804_nojava, ubuntu1804_java9, ubuntu1804_java10 to
    postsubmit.
  * Disable Android shell tests on the "nojava" platform.
  * Update bazel_toolchains to latest release.
  * Windows: fix writing java.log
  * Fix toolchain_java9 on --host_javabase=
  * Include also ext jars in the bootclasspath jar.
  * Do not fail the build when gcov is not installed
  * Ignore unrecognized VM options in desugar.sh, such as the JVM
    9 flags to silence warnings.
  * In the future, Bazel will expand tree artifacts in runfiles,
    too,which causes the sandbox to link each file individually
    into the sandbox directory, instead of symlinking the entire
    directory. In this release, the behavior is not enabled by
    default yet. Please try it out via --incompatible_symlinked_
    sandbox_expands_tree_artifacts_in_runfiles_tree and let us know
    if it causes issues. If everything looks good, this behavior
    will become the default in a following release.
* Thu Jun 28 2018 malcolmlewis@opensuse.org
- Update to version 0.15.0:
  + Bazel now always runs binaries in with "bazel run" in
    interactive mode. The "--nodirect_run" command line option is
    now a no-op.
  + "bazel run --noas_test" is not supported anymore.
  + Indentation on the first line of a file was previously ignored,
    this is now fixed.
  + New features:
  * C++,runfiles: to access data-dependencies (runfiles) in C++
    programs, use the runfiles library built into Bazel.
  + Bazel now allows almost all 7-bit ASCII characters in labels.
  + Remove vestigial java_plugin.data attribute
  + Bazel supports including select Java 8 APIs into Android apps
    targeting pre-Nougat Android devices with
  - -experimental_desugar_java8_libs
  + Flag --incompatible_disable_glob_tracking is removed.
  + SkyQuery's rbuildfiles now returns targets corresponding to
    broken packages.
  + Introduce build support for providing cache prefetch hints.
  + Update the skylark DefaultInfo documentation to spell out
    runfiles, data_runfiles and default_runfiles.
  + An internal action for symlinking runfiles will use Command
    instead of a Spawns. This should have no functional chages; the
    only user visible consequence should be that the internal
    action is no longer be included in statistics when calculating
    processes count.
  + --batch is deprecated
  + Execution strategies line no longer handles differently the
    case where all processes have the same strategy.
  + The --experimental_remote_spawn_cache flag is now enabled by
    default, and remote caching no longer needs --*_strategy=remote
    flags (it will fail if they are specified).
  + android_binary.aapt_version='aapt2' now supports en_XA and
    ar_XB.
  + With --incompatible_no_support_tools_in_action_inputs enabled,
    Skylark action inputs are no longer scanned for tools. Move any
    such inputs to the newly introduced 'tools' attribute.
- Changes from version 0.14.1:
  + Critical fixes for:
  * Sometime hangs before running any actions,
    (gh#bazelbuild/bazel/#5336).
  * Has no way to unset --disk_cache flag (interferes with
    remote build testing), (gh#bazelbuild/bazel/#5308).
- Changes from version 0.14.0:
  + Add --incompatible_disallow_legacy_javainfo flag.
  + Added flag --incompatible_disallow_old_style_args_add to help
    migrate from args.add() to args.add_all() / args.add_joined()
    where appropriate.
  + New features:
  * Bash,runfiles: use the new platform-independent library in
    @bazel_tools//tools/bash/runfiles to access runfiles
    (data-dependencies).
  * TemplateVariableInfo can now be constructed from Skylark.
  * The java_host_runtime_alias rule is now implemented in Java.
  + Introduce fdo_profile rule that allows architecture-sensitive
    specification of fdo profiles.
  + canonicalize-flags no longer reorders the flags
  + CppRules: optional_compiler_flag was removed from CROSSTOOL,
    use features instead.
  + Labels of the form ////foo are disallowed.
  + The / operator is deprecated in favor of // (floor integer
    division). Try the --incompatible_disallow_slash_operator flag
    to ensure your code is forward-compatible.
  + Flip default value of --experimental_shortened_obj_file_path to
    true, Bazel now generates short object file path by default.
  + Exposed "mnemonic" and "env" fields on skylark "Action"
    objects.
  + Removed flag --incompatible_disallow_toplevel_if_statement.
  + Remove vestigial 'deps' and 'data' attributes from
    proto_lang_toolchain
  + Args objects (ctx.actions.args()) have new methods add_all()
    and add_joined() for building command lines using depsets.
  + FileType is deprecated and will be removed soon.
  + Try the --incompatible_disallow_filetype flag to ensure your
    code is forward-compatible.
  + Introduce absolute_path_profile attribute that allows
    fdo_profile to accept absolute paths.
  + Support two-arg overloads for ctx.actions.args (eg.
    args.add("--foo", val))
  + Introduce 'tools' attribute to ctx.actions.run.
  + Fixed error message for proguard_apply_dictionary.
  + "bazel run" now lets one run interactive binaries.
  + Repository rules are no longer restricted to return None.
  + Add --high_priority_workers flag.
  + CppRules: Feature configuration can be created from Skylark
    Adds new-style JavaInfo provider constructor.
  + Make java_common.compile now uses java_toolchain javacopts by
    default; explicitly retrieving them using
    java_common.default_javac_opts is unnecessary.
  + CppRules: C++ command lines and env variables for C++ actions
    can be retrieved from feature configuration.
  + Skylark rule definitions may advertise providers that targets
    of the rule must propagate.
  + Bazel now supports running actions inside Docker containers.
    To use this feature, run "bazel build --spawn_strategy=docker
  - -experimental_docker_image=myimage:latest".
  + Fixing start/end lib expansion for linking. There were many
    cases where archive files were still being used with toolchains
    that support start/end lib. This change consolidates the places
    that make that decision so they can be more consistent.
  + Add support for reporting an error if
    android_test.binary_under_test contains incompatible versions
    of deps.
  + We replaced the --experimental_local_disk_cache and
  - -experimental_local_disk_cache_path flags into a single
  - -disk_cache flag. Additionally, Bazel now tries to create the
    disk cache directory if it doesn't exist.
  + Save Blaze memory by not storing LinkerInput objects in
    LinkCommandLine.
  + In the JavaInfo created by java_common.create_provider now
    includes both direct and transitive arguments in
    transitive_compile_time_jars and transitive_runtime_jars
  + Allow --worker_max_instances to take MnemonicName=value to
    specify max for each worker.
  + Allow java_toolchain.header_compiler to be an arbitrary
    executable.
- Changes from version 0.13.1:
  + Sort entries by segment when building a parent node to prevent
    unordered directory structures.
- Add attributions and license to package.
- FIXME, don't build bash-completion as it breaks build, plus
  it's not installed andyway.
* Thu May  3 2018 vrothberg@suse.com
- Update to 0.13.0
* Tue Mar  6 2018 mrostecki@suse.com
- Update to 0.11.0
* Thu Feb 15 2018 ndas@suse.de
- Do not strip  the binary
- Fix compilation issue
  [+0001-fix-no-return-compilation-error.patch+]
* Tue Dec 12 2017 plinnell@opensuse.org
- Inital Package 0.8.1
